@@ -1,14 +1,16 @@
 import seaborn as sns
 import pkg_resources
 from PIL import Image, ImageDraw, ImageFont
+import os
 
 
-def track_manager(pos_track=(0.95, 0.90, 0.85, 0.80), size=10.0):
+def get_track_template(pos_track=(0.95, 0.90, 0.85, 0.80), size=10.0, output_dir=os.getcwd()):
     """
     Generate file for Track Manager option in DNAPlotter
     :param pos_track: the positions for plotting features (CDS forward strand, CDS reverse strand, pseudogenes, RNA genes)
     :param size: the size of track
-    :return: track manager file
+    :param output_dir: the output file
+    :return: track template file
     """
     # position vector: 27x for CDS forward strand, 27x for CDS reverse strand, 27x for pseudogenes, 3x for RNA genes
     pos = [str(pos_track[0]), str(pos_track[1])] * 27
@@ -71,14 +73,14 @@ def track_manager(pos_track=(0.95, 0.90, 0.85, 0.80), size=10.0):
                  + NOT[i] + "\t" + ANY[i] + "\t" + KEY[i] + "\t" + QUAL[i] + "\t" + VAL[i] + \
                  "\t" + str(COL[i]) + "\n"
 
-    with open("track_template", "w") as file_to_save:
+    with open(output_dir + "/track_template", "w") as file_to_save:
         file_to_save.write(string)
         file_to_save.close()
 
 
-def get_legend():
+def get_legend(output_dir=os.getcwd()):
     """
-    Create a legend for genome map
+    Create a legend for the genome map
     """
     # color palette: 20 colors have been chosen from seaborn palette and other ten were selected subjectively
     palette = sns.color_palette('tab20')
@@ -102,4 +104,4 @@ def get_legend():
         image_edit.rectangle((50, start, 50 + 80, start + 80), fill=(palette[ind][0], palette[ind][1], palette[ind][2]))
         image_edit.text((150, start + 15), CATS[ind], font=myFont, fill=(0, 0, 0))
         start = start + 80
-    img.save('legend.jpg')
+    img.save(output_dir + '/legend.jpg')
